==> nextcloud-13.0.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/tr.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Yük ortalaması",
    "Last minute" : "Son dakika",
    "Memory info not available" : "Bellek bilgilerine erişilemiyor",
    "Total" : "Toplam",
    "Current usage" : "Güncel kullanım",
    "Users" : "Kullanıcılar",
    "Groups" : "Gruplar",
    "Links" : "Bağlantılar",
    "Federated sent" : "Birleşmiş gönderilen",
    "Federated received" : "Birleşmiş alınan",
    "Last 24 hours" : "Son 24 saat",
    "Last 1 hour" : "Son 1 saat",
    "Last 5 mins" : "Son 5 dakika",
    "Copy" : "Kopyala",
    "Copied!" : "Kopyalandı!",
    "Not supported!" : "Desteklenmiyor!",
    "Press ⌘-C to copy." : "Kopyalamak için ⌘-C tuşlarına basın.",
    "Press Ctrl-C to copy." : "Kopyalamak için Ctrl-C tuşlarına basın.",
    "Monitoring" : "İzleniyor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "İşlemci yükü, bellek ve disk kullanımı, kullanıcı sayısı gibi sunucu hakkında çeşitli bilgiler sağlar. ",
    "CPU load" : "İşlemci yükü",
    "Memory usage" : "Bellek kullanımı",
    "Active users" : "Etkin kullanıcılar",
    "Shares" : "Paylaşımlar",
    "Storage" : "Depolama",
    "Users:" : "Kullanıcılar:",
    "Files:" : "Dosyalar:",
    "PHP" : "PHP",
    "Version:" : "Sürüm:",
    "Memory Limit:" : "Bellek Sınırı:",
    "Max Execution Time:" : "En Uzun Çalışma Süresi:",
    "Upload max size:" : "En büyük yükleme boyutu:",
    "Database" : "Veritabanı",
    "Type:" : "Tür:",
    "Size:" : "Boyut:",
    "External monitoring tool" : "Dış izleme aracı",
    "You can connect an external monitoring tool by using this end point:" : "Bu uç noktasını kullanarak bir dış izleme aracı bağlayabilirsiniz:",
    "You can connect an external monitoring tool by using this end point: " : "Bu uç noktasını kullanarak bir dış izleme aracı bağlayabilirsiniz:"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/tr.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "İşlemci bilgileri alınamadı",
    "Load average" : "Yük ortalaması",
    "Last minute" : "Son dakika",
    "Memory info not available" : "Bellek bilgilerine erişilemiyor",
    "Total" : "Toplam",
    "Current usage" : "Güncel kullanım",
    "Users" : "Kullanıcılar",
    "Groups" : "Gruplar",
    "Links" : "Bağlantılar",
    "Federated sent" : "Birleşmiş gönderilen",
    "Federated received" : "Birleşmiş alınan",
    "Last 24 hours" : "Son 24 saat",
    "Last 1 hour" : "Son 1 saat",
    "Last 5 mins" : "Son 5 dakika",
    "Copy" : "Kopyala",
    "Copied!" : "Kopyalandı!",
    "Not supported!" : "Desteklenmiyor!",
    "Press ⌘-C to copy." : "Kopyalamak için ⌘-C tuşlarına basın.",
    "Press Ctrl-C to copy." : "Kopyalamak için Ctrl-C tuşlarına basın.",
    "Monitoring" : "İzleniyor",
    "Monitoring app with useful server information" : "Yararlı sunucu bilgileri sunan izleme uygulaması",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "İşlemci yükü, bellek ve disk kullanımı, kullanıcı sayısı gibi sunucu hakkında çeşitli bilgiler sağlar. ",
    "CPU load" : "İşlemci yükü",
    "Memory usage" : "Bellek kullanımı",
    "Active users" : "Etkin kullanıcılar",
    "Shares" : "Paylaşımlar",
    "Storage" : "Depolama",
    "Users:" : "Kullanıcılar:",
    "Files:" : "Dosyalar:",
    "Storages:" : "Depolama Birimleri:",
    "Free Space:" : "Boş Alan:",
    "Nextcloud" : "Nextcloud",
    "Version:" : "Sürüm:",
    "Apps installed:" : "Kurulu Uygulamalar:",
    "Apps updates available:" : "Güncellenebilecek Uygulamalar:",
    "PHP" : "PHP",
    "Memory Limit:" : "Bellek Sınırı:",
    "Max Execution Time:" : "En Uzun Çalışma Süresi:",
    "Upload max size:" : "En büyük yükleme boyutu:",
    "Database" : "Veritabanı",
    "Type:" : "Tür:",
    "Size:" : "Boyut:",
    "External monitoring tool" : "Dış izleme aracı",
    "You can connect an external monitoring tool by using this end point:" : "Bu uç noktasını kullanarak bir dış izleme aracı bağlayabilirsiniz:",
    "Did you know?" : "Biliyor musunuz?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Adresin sonuna \"?format=json\" eklendiğinde sonuçlar JSON biçiminde alınabilir!",
    "You can connect an external monitoring tool by using this end point: " : "Bu uç noktasını kullanarak bir dış izleme aracı bağlayabilirsiniz:"
},
"nplurals=2; plural=(n > 1);");
